<?php
/**
 * Handles comments for more precise control over their display
 * Many major issues with WP comments are dealt with
 *
 * @package Hybrid
 * @subpackage Functions 
 */

/**
 * Better display of avatars in comments
 * Should only be used in comment sections (may update in future)
 * Checks for false empty commenter URLs 'http://' w/registered users
 * Adds the class 'photo' to the image
 * Adds a call to HYBRID_IMAGES . '/trackback.jpg' for trackbacks
 * Adds a call to HYBRID_IMAGES . '/pingback.jpg' for pingbacks
 * Checks for trackbacks and pingbacks (jpg, png, gif) files in child theme's '/images' folder first
 *
 * Filter hybrid_avatar to override default avatar functionality
 * Prior to version 0.5, only the $default_avatar could be set
 *
 * @since 0.2
 */
function hybrid_avatar() {
	global $comment, $hybrid_settings;

	/*
	* Image types that can be used for trackback/pingback avatars
	*/
	$img_arr = array( '.jpg', '.png', '.gif' );

	/*
	* Get/set some comment variables
	*/
	$avatar = false;
	$comment_type = get_comment_type();
	$author = get_comment_author();
	$url = get_comment_author_url();
	if ( $url == 'http://' )
		$url = false;

	/*
	* Check for the trackback avatar
	*/
	if ( $comment_type == 'trackback' ) :
		foreach ( $img_arr as $img ) :
			if ( file_exists( HYBRID_CHILD_DIR . '/images/trackback' . $img ) ) :
				$default_avatar = HYBRID_CHILD_URL . '/images/trackback' . $img;
				break;
			endif;
		endforeach;
		if ( !$default_avatar ) :
			$default_avatar = HYBRID_IMAGES . '/trackback.jpg';
		endif;

	/*
	* Check for the pingback avatar
	*/
	elseif ( $comment_type == 'pingback' ) :
		foreach ( $img_arr as $img ) :
			if ( file_exists( HYBRID_CHILD_DIR . '/images/pingback' . $img ) ) :
				$default_avatar = HYBRID_CHILD_URL . '/images/pingback' . $img;
				break;
			endif;
		endforeach;
		if ( !$default_avatar ) :
			$default_avatar = HYBRID_IMAGES . '/pingback.jpg';
		endif;

	/*
	* Check for the default avatar
	* This can be set in the theme settings
	*/
	elseif ( $hybrid_settings['default_avatar'] ) :
		$default_avatar = $hybrid_settings['default_avatar'];

	endif;

	/*
	* If URL input, open hyperlink
	*/
	if ( $url )
		$avatar .= '<a href="' . $url . '" rel="external nofollow" title="' . wp_specialchars( $author, 1 ) . '">';

	/*
	* Get the avatar and add the class 'photo'
	*/
	$avatar .= str_replace( array( "class='avatar", "alt=''" ), array( "class='photo avatar", "alt='" . wp_specialchars( $author, 1 ) . "'" ), get_avatar( get_comment_author_email(), '80', $default_avatar ) );

	/*
	* Close hyperlink
	*/
	if ( $url )
		$avatar .= '</a>';

	echo apply_filters( 'hybrid_avatar', $avatar );
}

/**
 * Displays individual comments
 * Uses the callback parameter for wp_list_comments()
 * Overwrites the default display of comments
 *
 * @since 0.2.3
 *
 * @param $comment The comment variable
 * @param $args Array of arguments passed from wp_list_comments()
 * @param $depth What level the particular comment is
 */
function hybrid_comments_callback( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	$GLOBALS['comment_depth'] = $depth;
?>

	<li id="comment-<?php echo $comment->comment_ID; ?>" class="<?php hybrid_comment_class(); ?>">

		<?php hybrid_before_comment(); // Before comment hook ?>

		<?php hybrid_avatar(); // Avatar filter hook ?><div class="comment-meta-data">

			<div class="comment-author vcard">
				<?php hybrid_comment_author(); ?>
			</div>

			<abbr class="comment-time" title="<?php comment_date( __('l, F jS, Y, g:i a', 'hybrid') ); ?>">
				<?php printf( __('%1$s at %2$s', 'hybrid'), get_comment_date(), get_comment_time() ); ?>
			</abbr> 

			<span class="separator">|</span> 
			<a class="permalink" href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>" title="<?php printf( __('Permalink to comment %1$s', 'hybrid'), $comment->comment_ID ); ?>"><?php _e('Permalink', 'hybrid'); ?></a>

			<?php
				if ( ( get_option('thread_comments') ) && ( $args['type'] == 'all' || get_comment_type() == 'comment' ) ) :
					$max_depth = get_option( 'thread_comments_depth' );
					echo comment_reply_link( array(
						'reply_text' => __('Reply', 'hybrid'), 
						'login_text' => __('Log in to reply.', 'hybrid'),
						'depth' => $depth,
						'max_depth' => $max_depth, 
						'before' => '<span class="separator">|</span> <span class="comment-reply-link">', 
						'after' => '</span>'
					) );
				endif;
			?>

			<?php edit_comment_link( '<span class="edit">' . __('Edit', 'hybrid') . '</span>', ' <span class="separator">|</span> ', '' ); ?> 

			<?php if ( $comment->comment_approved == '0' ) : ?>
				<em><?php _e('Your comment is awaiting moderation.', 'hybrid'); ?></em>
			<?php endif; ?>

		</div>

		<div class="comment-text">
			<?php comment_text(); ?>
		</div>
<?php
}

/**
 * Ends the display of individual comments
 * Uses the callback parameter for wp_list_comments()
 * Needs to be used in conjunction with hybrid_comments_callback()
 * Not needed but used just in case something is changed
 *
 * @since 0.2.3
 */
function hybrid_comments_end_callback() {
		hybrid_after_comment(); // After comment hook
	echo '</li>';
}

/**
 * Properly displays comment author name/link
 * bbPress and other external systems sometimes don't set a display name for registrations
 * WP has problems if no display name is set
 * WP gives registered users URL of 'http://' if none is set
 *
 * @since 0.2.2
 */
function hybrid_comment_author() {
	global $comment;

	$author = get_comment_author();
	$url = get_comment_author_url();

	/*
	* Registered members w/o URL defaults to 'http://'
	*/
	if ( $url == 'http://' )
		$url = false;

	/*
	* Registered through bbPress sometimes leaves no display name
	* Bug with bbPress 0.9 series and WP 2.5 (no later testing)
	* 'Anonymous' should be localized according to WP, not the theme
	*/
	if ( $comment->user_id > 0 ) :
		$user = get_userdata( $comment->user_id );
		if ( $user->display_name )
			$author = $user->display_name;
		elseif ( $user->user_nickname )
			$author = $user->nickname;
		elseif ( $user->user_nicename )
			$author = $user->user_nicename;
		elseif ( $user->user_login )
			$author = $user->user_login;
	endif;

	/*
	* Display link and cite if URL is set
	* Also properly cites trackbacks/pingbacks
	*/
	if ( $url ) :
		$output = '<cite class="fn" title="' . $url . '">';
		$output .= '<a href="' . $url . '" title="' . wp_specialchars( $author, 1 ) . '" class="url external nofollow">' . $author . '</a>';
		$output .= '</cite>';
	else :
		$output = '<cite class="fn">';
		$output .= $author;
		$output .= '</cite>';
	endif;

	echo apply_filters( 'hybrid_comment_author', $output );
}

/**
 * Shows a link to subscribe to the comments
 * Don't display link if using Subscribe To Comments
 * Don't show this by default
 * Child themes could use add_action() to hook this to the comment form
 *
 * @since 0.4
 */
function hybrid_comments_feed() {
	if ( !function_exists( 'show_subscription_checkbox' ) ) :
		echo '<p class="comments-feed">';
		comments_rss_link( __('Subscribe to the comments feed to follow this discussion.', 'hybrid') );
		echo '</p>';
	endif;
}

?>