<?php
/**
 * Main functions file for the Hybrid framework
 * These are various functions used throughout the theme
 * Most output can be filtered with your custom functions
 * Many of the functions in this file are run before the templates
 * Generally, these are functions that are added to hybrid_head
 *
 * @package Hybrid
 * @subpackage Functions
 */

/**
 * Adds the correct DOCTYPE to the theme
 * Defaults to XHTML 1.0 Strict
 * Child themes can overwrite this with the hybrid_doctype filter
 *
 * @since 0.4
 */
function hybrid_doctype() {
	$browser = $_SERVER[ 'HTTP_USER_AGENT' ];
	if ( !preg_match( "/MSIE 6.0/", $browser ) )
		echo '<?xml version="1.0" encoding="' . get_bloginfo( 'charset' ) . '"?>' . "\n";

	$doctype = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">' . "\n";
	echo apply_filters( 'hybrid_doctype', $doctype );
}

/**
 * Function for handling what the browser/search engine title should be
 * Tries to handle every situation to make for the best SEO
 *
 * Check for All-in-One SEO and HeadSpace2 for compatibility
 * Use the filter hybrid_document_title to create your own
 * @link http://wordpress.org/extend/plugins/all-in-one-seo-pack
 * @link http://wordpress.org/extend/plugins/headspace2
 *
 * @todo Make this easy to filter with custom functions
 *
 * @since 0.1
 * @return string
 */
function hybrid_document_title() {
	global $post, $wp_query, $hybrid_settings;
	
	/*
	* Make compatible with plugins
	* All-in-One SEO Pack
	* HeadSpace2
	*/
	if ( class_exists( 'All_in_One_SEO_Pack' ) || class_exists( 'HeadSpace2_Admin' ) ) :
		wp_title( '' );
		return;
	endif;

	$doctitle = array();

	/*
	* Contextual document title
	*/
	if ( is_front_page() || is_home() ) :
		$content = '';
	elseif ( is_attachment() ) :
		$content = single_post_title( false, false );
	elseif ( is_single() || is_page() ) :
		$content = wp_specialchars( get_post_meta( $post->ID, 'Title', true ), true );
		if ( !$content ) :
			$content = single_post_title( false, false );
		else :
			$subtitle = wp_specialchars( get_post_meta( $post->ID, 'Subtitle', true ), true );
			if ( $subtitle ) $content .= ': ' . $subtitle;
		endif;
	elseif ( is_category() ) :
		$content = single_cat_title( false, false );
	elseif ( is_tag() ) :
		$content = single_tag_title( false, false );
	elseif ( is_author() ) :
		$content = wp_title( false, false, false );
	elseif ( is_search() ) :
		$content = sprintf( __('Search results for &quot;%1$s&quot;', 'hybrid'), attribute_escape( get_search_query() ) );
	elseif ( is_day() ) :
		$content = sprintf( __('Archive for %1$s', 'hybrid'), get_the_time( __('F jS, Y', 'hybrid') ) );
	elseif ( get_query_var( 'w' ) ) :
		$content = sprintf( __('Archive for week %1$s of %2$s', 'hybrid'), get_the_time( __('W', 'hybrid') ), get_the_time( __('Y', 'hybrid') ) );
	elseif ( is_month() ) :
		$content = sprintf( __('Archive for %1$s', 'hybrid'), single_month_title( ' ', false) );
	elseif ( is_year() ) :
		$content = sprintf( __('Archive for %1$s', 'hybrid'), get_the_time( __('Y', 'hybrid') ) );
	elseif ( is_comments_popup() ) :
		$content = sprintf( __('Comment on &quot;%1$s&quot;', 'hybrid'), single_post_title( false, false ) );
	elseif ( is_404() ) :
		$content = __('404 Not Found', 'hybrid');
	else :
		$content = wp_title( false, false, false );
	endif;

	/*
	* Set everything in array
	*/
	$doctitle['sitename'] = get_bloginfo( 'name' );
	$doctitle['tagline'] = get_bloginfo( 'description' );
	$doctitle['separator'] = ':';
	$doctitle['content'] = $content;

	/*
	* Not quite ready to apply filters (maybe 0.5.1)
	*/
	//$doctitle = apply_filters( 'hybrid_document_title', $doctitle );

	/*
	* If paged
	*/
	if ( ( ( $page = $wp_query->get( 'paged' ) ) || ( $page = $wp_query->get( 'page' ) ) ) && $page > 1 )
		$doctitle['content'] .= sprintf( __('%1$s Page %2$s', 'hybrid'), $doctitle['separator'], $page );

	extract( $doctitle );

	/*
	* What should be output
	* Check Hybrid settings to put everything in correct order
	*/
	if ( ( $hybrid_settings['seo_tagline_before_title'] && $hybrid_settings['seo_show_tagline'] ) && ( is_home() || is_front_page() ) )
		$title = $tagline . $separator . ' ' . $sitename . $content;
	elseif ( $hybrid_settings['seo_show_tagline'] && ( is_home() || is_front_page() ) )
		$title = $sitename . $separator . ' ' . $tagline . $content;
	elseif ( is_home() || is_front_page() )
		$title = $sitename . $content;
	elseif ( ( !is_home() && !is_front_page() ) && $hybrid_settings['seo_blog_title'] )
		$title = $content . $separator . ' ' . $sitename;
	else
		$title = $content;

	echo $title;
}

/**
 * Shows the content type in the header
 * Gets the site's defined HTML type and charset
 * Can be overwritten with the hybrid_meta_content_type filter
 *
 * @since 0.4
*/
function hybrid_meta_content_type() {
	$content_type = '<meta http-equiv="Content-Type" content="' . get_bloginfo( 'html_type' ) . ' charset=' . get_bloginfo( 'charset' ) . '" />' . "\n";
	echo apply_filters( 'hybrid_meta_content_type', $content_type );
}

/**
 * Allows/disallows indexing by search engines
 * Calls theme settings to check for data
 * Check options 'blog_public' for privacy mode
 * If private, don't send meta info to header
 * Runs the hybrid_meta_robots filter hook at the end
 *
 * @since 0.2.3
 */
function hybrid_meta_robots() {
	global $post, $hybrid_settings, $wp_query;

	if ( !get_option( 'blog_public' ) || class_exists( 'All_in_One_SEO_Pack' ) || class_exists( 'HeadSpace2_Admin' ) )
		return;

	/*
	* Indexing/Robots
	*/
	if ( ( is_home() || is_front_page() ) && ( $hybrid_settings['robots_home'] ) )
		$follow = true;
	elseif ( is_attachment() && $hybrid_settings['robots_attachment'] )
		$follow = true;
	elseif ( is_single() && !is_attachment() && $hybrid_settings['robots_single'] )
		$follow = true;
	elseif ( is_page() && !is_front_page() && $hybrid_settings['robots_page'] )
		$follow = true;
	elseif ( is_date() && $hybrid_settings['robots_date'] )
		$follow = true;
	elseif ( is_category() && $hybrid_settings['robots_category'] )
		$follow = true;
	elseif ( is_tag() && $hybrid_settings['robots_tag'] )
		$follow = true;
	elseif ( is_search() && $hybrid_settings['robots_search'] )
		$follow = true;
	elseif ( is_author() && $hybrid_settings['robots_author'] )
		$follow = true;
	elseif ( is_404() && $hybrid_settings['robots_404'] )
		$follow = true;
	else
		$follow = false;

	if ( is_singular() && get_option( 'page_comments' ) ) :
		if ( isset( $wp_query->query['cpage'] ) && absint( $wp_query->query['cpage'] ) >= 1 ) :
			$follow = false;
		endif;
	endif;

	if ( $follow )
		$robots = '<meta name="robots" content="index,follow" />' . "\n";
	else
		$robots = '<meta name="robots" content="noindex,follow" />' . "\n";

	echo apply_filters( 'hybrid_meta_robots', $robots );
}

/**
 * Meta abstract tag
 * Should only be used with highly specialized fields
 * Good for research papers and studies but will not help/hurt SEO
 * Input 10 words or less
 * Uses the custom field key 'Abstract'
 *
 * @since 0.4
 */
function hybrid_meta_abstract() {
	global $post;
	if ( get_post_meta( $post->ID, 'Abstract', $single = true ) )
		echo '<meta name="abstract" content="' . wp_specialchars( $abstract, 1 ) . '" />' . "\n";
}

/**
 * Generates the meta author
 * Uses post/page author's name as author
 * Order of importance:
 *	- First/last name, display name, nickname, username
 *
 * @since 0.3.3
 */
function hybrid_meta_author() {
	global $wp_query, $post, $hybrid_settings;

	if ( (is_single() || is_page() ) && $hybrid_settings['seo_meta_author'] ) :
		$curauth = get_userdata( $wp_query->post->post_author );
		if ( $curauth->first_name && $curauth->last_name ) :
			$meta_author = $curauth->first_name . ' ' . $curauth->last_name;
		elseif ( $curauth->display_name ) :
			$meta_author = $curauth->display_name;
		elseif ( $curauth->nickname ) :
			$meta_author = $curauth->nickname;
		elseif ( $curauth->user_nicename ) :
			$meta_author = $curauth->user_nicename;
		else :
			$meta_author = $curauth->user_login;
		endif;
	endif;

	if ( $meta_author )
		echo '<meta name="author" content="' . $meta_author . '" />' . "\n";
}

/**
 * Add the meta tag for copyright information to the header
 * Single posts and pages should display the date written
 * All other pages will show the current year
 *
 * @since 0.4
 */
function hybrid_meta_copyright() {
	if ( is_single() || is_page() )
		$date = get_the_time( __('F Y', 'hybrid') );
	else
		$date = date( __('Y', 'hybrid') );

	$copyright = sprintf( __('Copyright (c) %1$s', 'hybrid'), $date );
	echo '<meta name="copyright" content="' . $copyright . '" />' . "\n";
}

/**
 * Add the revised meta tag on single posts and pages
 * This shows the last time the post/page was modified
 *
 * @since 0.4
 */
function hybrid_meta_revised() {
	if ( is_single() || is_page() ) :
		$date = get_the_modified_time( __('l, F jS, Y, g:i a', 'hybrid') );
		echo '<meta name="revised" content="' . $date . '" />' . "\n";
	endif;
}

/**
 * Generates the meta description
 * Checks theme settings for indexing, title, and meta settings
 * Customize this with the hybrid_meta_description filter
 *
 * @since 0.2.3
 */
function hybrid_meta_description() {
	global $post, $hybrid_settings, $wp_query;

	if ( class_exists( 'All_in_One_SEO_Pack' ) || class_exists( 'HeadSpace2_Admin' ) )
		return;

	/*
	* Get meta description
	* Check for custom fields on posts/pages
	*/
	if ( is_home() || is_front_page() ) :
		$meta_desc = get_bloginfo( 'description' );

	elseif ( is_single() || is_page() ) :
		$meta_desc = get_post_meta( $post->ID, 'Description', true );

		if ( !$meta_desc && $hybrid_settings['seo_single_excerpts'] ) :
			$meta_desc = get_the_excerpt();
		endif;

	elseif ( is_category() ) :
		$meta_desc = stripslashes( strip_tags( category_description() ) );

	elseif ( is_author() ) :
		$meta_auth = get_userdata( get_query_var( 'author' ) );
		$meta_desc = str_replace( array( '"' ), '&quot;', $meta_auth->description );

	endif;

	if ( !$meta_desc || strlen( $meta_desc ) <= 1 )
		return;

	/*
	* Meta description
	*/
	$meta_desc = str_replace( array( "\r", "\n", "\t" ), '', wp_specialchars( $meta_desc, 1 ) );
	$meta_desc = '<meta name="description" content="' . $meta_desc . '" />' . "\n";
	echo apply_filters( 'hybrid_meta_description', $meta_desc );
}

/**
 * Generates meta keywords/tags for the site
 * Checks theme settings
 * Checks indexing settings
 * Customize with the hybrid_meta_keywords filter
 *
 * @since 0.2.3
 */
function hybrid_meta_keywords() {
	global $post, $hybrid_settings, $wp_query;

	if ( class_exists( 'All_in_One_SEO_Pack' ) || class_exists( 'HeadSpace2_Admin' ) )
		return;

	/*
	* If on a single post
	* Check for custom fields
	* Check for SEO settings
	*/
	if ( is_single() && !is_preview() && !is_attachment() ) :
		$post_keywords = get_post_meta( $post->ID, 'Keywords', true );
		if ( $post_keywords )
			$keywords[] = $post_keywords;

		 if( $hybrid_settings['seo_cats'] && !$post_keywords ) :
			$cats = get_the_category();
			if ( $cats ) :
				foreach( $cats as $cat ) :
					$keywords[] = $cat->name;
				endforeach;
			endif;
		endif;
		if ( $hybrid_settings['seo_tags'] && !$post_keywords ) :
			$wp_query->in_the_loop = true;
			$tags = get_the_tags();
			if ( $tags ) :
				foreach ( $tags as $tag ) :
					$keywords[] = $tag->name;
				endforeach;
			endif;
			$wp_query->in_the_loop = false;
		endif;

	/*
	* Check for custom field key Keywords
	*/
	elseif(is_page() && !is_preview()) :
		$post_keywords = get_post_meta( $post->ID, 'Keywords', true );
		if ( $post_keywords )
			$keywords[] = $post_keywords;
	endif;

	if ( !empty( $keywords ) ) :
		$keywords = join( ', ', $keywords );
		$keywords = '<meta name="keywords" content="' . wp_specialchars( $keywords, 1 ) . '" />' . "\n";
	endif;

	echo apply_filters( 'hybrid_meta_keywords', $keywords );
}

/**
 * Generates the relevant template info
 * Adds template meta with theme version
 * Uses the theme name and version from style.css
 *
 * @since 0.4
 */
function hybrid_meta_template() {
	$data = get_theme_data( TEMPLATEPATH . '/style.css' );
	echo '<meta name="template" content="' . $data['Title'] . ' ' . $data['Version'] . '" />' . "\n";
}

/**
 * Checks for a user-uploaded favicon
 * Looks in the child theme's /images folder
 * Customize with the hybrid_favicon filter
 *
 * @since 0.4
 */
function hybrid_favicon() {
	if ( file_exists( HYBRID_CHILD_DIR . '/images/favicon.ico' ) ) :
		$favicon = HYBRID_CHILD_URL . '/images/favicon.ico';
		$favicon =  '<link rel="shortcut icon" type="image/x-icon" href="' . $favicon . '" />' . "\n";
		echo apply_filters( 'hybrid_favicon', $favicon );
	endif;
}

/**
 * Adds feed links to header
 * Feeds are dynamic, displayed according to page
 * Also checks for Hybrid feed settings
 * Customize with the hybrid_head_feeds filter
 *
 * @since 0.4
 */
function hybrid_head_feeds() {
	global $wp_query, $post, $hybrid_settings;

	if ( function_exists( 'automatic_feed_links' ) )
		automatic_feed_links( false );

	/*
	* Checks if all feeds should be directed to alternate feed address
	*/
	if ( $hybrid_settings['feeds_redirect'] ) :
		$rdf = $hybrid_settings['feed_url'];
		$rss2 = $hybrid_settings['feed_url'];
		$rss = $hybrid_settings['feed_url'];
		$atom = $hybrid_settings['feed_url'];
	/*
	* Category feeds
	*/
	elseif ( is_category() ) :
		$cat = $wp_query->get_queried_object();
		$rdf = get_category_feed_link( $cat->term_id, 'rdf' );
		$rss2 = get_category_feed_link( $cat->term_id, 'rss2' );
		$rss = get_category_feed_link( $cat->term_id, 'rss' );
		$atom = get_category_feed_link( $cat->term_id, 'atom' );
	/*
	* Tag feeds
	*/
	elseif ( is_tag() ) :
		$tag = $wp_query->get_queried_object();
		$rdf = get_tag_feed_link( $tag->term_id, 'rdf' );
		$rss2 = get_tag_feed_link( $tag->term_id, 'rss2' );
		$rss = get_tag_feed_link( $tag->term_id, 'rss' );
		$atom = get_tag_feed_link( $tag->term_id, 'atom' );
	/*
	* Author feeds
	*/
	elseif ( is_author() ) :
		$author = $wp_query->get_queried_object();
		$rdf = get_author_feed_link( $author->ID, 'rdf' );
		$rss2 = get_author_feed_link( $author->ID, 'rss2' );
		$rss = get_author_feed_link( $author->ID, 'rss' );
		$atom = get_author_feed_link( $author->ID, 'atom' );
	/*
	* Search feeds
	*/
	elseif ( is_search() ) :
		$search = attribute_escape( get_search_query() );
		$rdf = get_search_feed_link( $search, 'rdf' );
		$rss2 = get_search_feed_link( $search, 'rss2' );
		$rss = get_search_feed_link( $search, 'rss' );
		$atom = get_search_feed_link( $search, 'atom' );
	/*
	* Normal blog feeds
	*/
	else :
		$rdf = get_bloginfo( 'rdf_url' );
		$rss2 = get_bloginfo( 'rss2_url' );
		$rss = get_bloginfo( 'rss_url' );
		$atom = get_bloginfo( 'atom_url' );
	endif;

	/*
	* Comments feed
	*/
	if ( ( is_single() && comments_open() ) || ( is_page() && comments_open() ) )
		$comments_rss2 = get_post_comments_feed_link( $post->ID );
	else
		$comments_rss2 = get_bloginfo( 'comments_rss2_url' );

	/*
	* Format and display the feeds for <head>
	*/
	$feeds = false;
	if ( $rss2 )
		$feeds .= '<link rel="alternate" type="application/rss+xml" title="' . __('RSS 2.0', 'hybrid') . '" href="' . $rss2 . '" />' . "\n";
	if ( $rdf )
		$feeds .= '<link rel="alternate" type="application/rss+xml" title="' . __('RDF/RSS 1.0', 'hybrid') . '" href="' . $rdf . '" />' . "\n";
	if ( $rss )
		$feeds .= '<link rel="alternate" type="text/xml" title="' . __('RSS .92', 'hybrid') . '" href="' . $rss . '" />' . "\n";
	if ( $atom )
		$feeds .= '<link rel="alternate" type="application/atom+xml" title="' . __('Atom 0.3', 'hybrid') . '" href="' . $atom . '" />' . "\n";
	if ( $comments_rss2 )
		$feeds .= '<link rel="alternate" type="application/rss+xml" title="' . __('Comments RSS 2.0', 'hybrid') . '" href="' . $comments_rss2 . '" />' . "\n";

	echo apply_filters( 'hybrid_head_feeds', $feeds );
}

/**
 * Display pingback info in <head>
 * @uses get_bloginfo() Gets the pingback URL
 * @link http://codex.wordpress.org/Template_Tags/get_bloginfo
 *
 * @since 0.4
 */
function hybrid_head_pingback() {
	echo '<link rel="pingback" href="' . get_bloginfo( 'pingback_url' ) . '" />' . "\n";
}

/**
 * Adds <link rel="canonical"> to <head>
 * This is a marker for search engines to recognize the correct URL
 * Helps by reducing duplicate content issues
 * Use the hybrid_head_canonical filter to customize
 *
 * No URL set for 'page n' on single posts, pages, or attachments when using <!--nextpage-->
 *
 * @since 0.5
 */
function hybrid_head_canonical() {
	global $wp_query, $post;

	if ( is_paged() ) :
		$canonical = '<link rel="canonical" href="' . clean_url( get_pagenum_link( $page ) ) . '" />' . "\n";
		echo apply_filters( 'hybrid_head_canonical', $canonical );
		return;
	endif;

	/*
	* Canonical URLs
	* Not handling paginated posts/pages yet
	*/
	if ( ( ( $page = $wp_query->get( 'paged' ) ) || ( $page = $wp_query->get( 'page' ) ) ) && $page > 1 )
		return;

	if ( is_attachment() ) :
		$canonical = '<link rel="canonical" href="' . get_attachment_link( $wp_query->post->ID ) . '" />' . "\n";
	elseif ( is_page() ) :
		$canonical = '<link rel="canonical" href="' . get_page_link( $wp_query->post->ID ) . '" />' . "\n";
	elseif ( is_single() ) :
		$canonical = '<link rel="canonical" href="' . get_permalink() . '" />' . "\n";
	elseif ( is_front_page() ) :
		$canonical = '<link rel="canonical" href="' . get_bloginfo( 'url' ) . '" />' . "\n";
	elseif ( is_day() ) :
		$canonical = '<link rel="canonical" href="' . get_day_link( get_the_time( 'Y' ), get_the_time( 'm' ), get_the_time( 'd' ) ) . '" />' . "\n";
	elseif ( is_month() ) :
		$canonical = '<link rel="canonical" href="' . get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ) . '" />' . "\n";
	elseif ( is_year() ) :
		$canonical = '<link rel="canonical" href="' . get_year_link( get_the_time( 'Y' ) ) . '" />' . "\n";
	elseif ( is_category() ) :
		$cat = $wp_query->get_queried_object();
		$canonical = '<link rel="canonical" href="' .  get_category_link( $cat->term_id ) . '" />' . "\n";
	elseif ( is_tag() ) :
		$tag = $wp_query->get_queried_object();
		$canonical = '<link rel="canonical" href="' . get_tag_link( $tag->term_id ) . '" />' . "\n";
	elseif ( is_author() ) :
		$author = $wp_query->get_queried_object();
		$canonical = '<link rel="canonical" href="' . get_author_posts_url( $author->ID, $author->user_nicename ) . '" />' . "\n";
	endif;

	echo apply_filters( 'hybrid_head_canonical', $canonical );
}

/**
 * Breadcrumbs for <head>
 * Provides accessibility options for impaired users
 * Allows easier navigation through pages for screen readers
 *
 * @since 0.4
 */
function hybrid_head_breadcrumb() {
	global $post;

	$prev = get_previous_post();
	$next = get_next_post();

	/*
	* Breadcrumbs
	*/
	if ( !is_front_page() )
		echo '<link rel="home" title="' . get_bloginfo( 'name' ) . '" href="' . get_bloginfo( 'url' ) . '" />' . "\n";
	if ( is_single() || is_page() )
		echo '<link rel="bookmark" title="' . the_title_attribute( 'echo=0' ) . '" href="' . get_permalink() . '" />' . "\n";
	if ( $prev )
		echo '<link rel="previous" title="' . wp_specialchars( $prev->post_title, 1 ) . '" href="' . get_permalink( $prev->ID ) . '" />' . "\n";
	if ( $next )
		echo '<link rel="next" title="' . wp_specialchars( $next->post_title, 1 ) . '" href="' . get_permalink( $next->ID ) . '" />' . "\n";

	echo "\n";
}

/**
 * Archived and single navigation links
 * Check for WP PageNavi plugin first on home/search/archives
 * @link http://wordpress.org/extend/plugins/wp-pagenavi
 *
 * @since 0.2
 */
function hybrid_navigation_links() {

	if ( is_home() || is_archive() || is_search() || is_page_template( 'blog.php' ) || is_page_template( 'excerpts.php' ) ) :

		if ( function_exists( 'wp_pagenavi' ) ) :
			wp_pagenavi();
		else : ?>
			<div class="navigation-links">
				<?php posts_nav_link(
					'',
					'<span class="previous">&laquo; ' . __('Previous Page', 'hybrid') . '</span>',
					'<span class="next">' . __('Next Page', 'hybrid') . ' &raquo;</span>'
				); ?>
			</div>

		<?php endif;

	elseif ( is_single() || is_attachment() ) : ?>

		<div class="navigation-links">
			<?php previous_post_link( '<span class="previous">&laquo; %link</span>' ); ?> 
			<?php next_post_link( '<span class="next">%link &raquo;</span>' ); ?>
		</div>
	<?php
	endif;
}

/**
 * Footer insert from the theme settings page
 * Uses stripslashes() for proper output of code
 *
 * @since 0.2.1
 */
function hybrid_footer_insert() {
	global $hybrid_settings;
	if ( $hybrid_settings['footer_insert'] )
		echo stripslashes( $hybrid_settings['footer_insert'] );
}

/**
 * Gets legacy functions if needed
 * For versions pre-2.7
 *
 * @todo Get rid of all WP 2.5 compatibility
 * @todo Get rid of all WP 2.6 compatibility (once 2.8 arrives)
 *
 * @since 0.3
 */
function hybrid_legacy_functions() {
	if ( !function_exists( 'wp_list_comments' ) )
		require_once( HYBRID_LEGACY . '/legacy.functions.php' );
}

/**
 * Grabs series by custom field
 * Checks for other articles in the series
 * Series identified custom field key 'Series' and unique value
 *
 * @since 0.3.1
 */
function hybrid_series() {
	global $post;
	$series = get_post_meta( $post->ID, 'Series', true );
	if ( $series ) :
		$args = array(
			'numberposts' => -1,
			'meta_key' => 'Series',
			'meta_value' => $series,
		);
		$series_posts = get_posts( $args );
		if ( $series_posts ) :
			$class = preg_replace( "/[^a-z0-9\\040\\.\\-\\_\\\\]/i", "", $series );
			$class = strtolower( str_replace( array( ' ', '&nbsp;' ), '-', $class ) );
			echo '<div class="series series-' . $class . '"><h4 class="series-title">' . __('Articles in this series', 'hybrid') . '</h4><ul>';
			foreach ( $series_posts as $serial ) :
				if ( $serial->ID == $post->ID )
					echo '<li class="current-post">' . $serial->post_title . '</li>';
				else
					echo '<li><a href="' . get_permalink( $serial->ID ) . '" title="' . wp_specialchars( $serial->post_title, 1 ) . '">' . $serial->post_title . '</a></li>';
			endforeach;
			echo '</ul></div>';
		endif;
	endif;
}

/**
 * Error output message
 * Shouldn't be used much, but just in case, it's here
 *
 * @since 0.2
 * @return string
 */
function hybrid_error() {
	_e('You have encountered an error. This is usually because you\'ve changed something in the core Hybrid theme files. Try undoing your last edit to correct this issue. If this doesn\'t resolve it, head over to the support forums for help.', 'hybrid');
}

/**
 * Displays query count and load time. Appended to the footer 
 * if user chooses this option from the theme settings page.
 * @uses current_user_can() to check for a user that can switch
 * themes.  Only those users can see the query count.
 *
 * @since 0.2.1
 */
function hybrid_query_counter() {
	global $hybrid_settings;
	if ( $hybrid_settings['query_counter'] && current_user_can( 'switch_themes' ) ) :
		echo '<p class="query-count">';
		printf( __('This page loaded in %1$s seconds with %2$s database queries.', 'hybrid'), timer_stop( 0, 3 ), get_num_queries() );
		echo '</p>';
	endif;
}

/**
 * Returns all authors with posts
 * Needed for use with the Authors page template
 *
 * @since 0.2.2
 *
 * @param array $args Mixed arguments (currently can only change $order_by)
 * @return array Authors with posts
 */
function hybrid_get_authors( $args = array() ) {
	global $wpdb;

	/*
	* Set up defaults and mix with $args
	*/
	$defaults = array(
		'order_by' => 'display_name',
	);

	$args = wp_parse_args( $args, $defaults );
	extract( $args );

	$user_ids = $wpdb->get_results( "SELECT COUNT(b.ID) AS postsperuser, a.ID as post_id, display_name, user_nicename, b.ID as ID FROM $wpdb->posts AS a LEFT join $wpdb->users AS b ON a.post_author = b.ID GROUP BY b.ID ORDER BY $order_by" );
	return $user_ids;
}

?>